==> beast-0.5.5.tar.gz: beast-0.5.5/beast-gtk/bstenum_arrays.c <==

/* Generated data (by glib-mkenums) */


/* --- bstfiledialog.h --- */
#include	"bstfiledialog.h"
/* BstFileDialogMode
 */
static GEnumValue bst_file_dialog_mode_values[] = {
  { BST_FILE_DIALOG_OPEN_PROJECT, "BST_FILE_DIALOG_OPEN_PROJECT", "open-project" },
  { BST_FILE_DIALOG_MERGE_PROJECT, "BST_FILE_DIALOG_MERGE_PROJECT", "merge-project" },
  { BST_FILE_DIALOG_SAVE_PROJECT, "BST_FILE_DIALOG_SAVE_PROJECT", "save-project" },
  { BST_FILE_DIALOG_SELECT_DIR, "BST_FILE_DIALOG_SELECT_DIR", "select-dir" },
  { BST_FILE_DIALOG_LOAD_WAVE, "BST_FILE_DIALOG_LOAD_WAVE", "load-wave" },
  { BST_FILE_DIALOG_LOAD_WAVE_LIB, "BST_FILE_DIALOG_LOAD_WAVE_LIB", "load-wave-lib" },
  { BST_FILE_DIALOG_MERGE_EFFECT, "BST_FILE_DIALOG_MERGE_EFFECT", "merge-effect" },
  { BST_FILE_DIALOG_MERGE_INSTRUMENT, "BST_FILE_DIALOG_MERGE_INSTRUMENT", "merge-instrument" },
  { BST_FILE_DIALOG_SAVE_EFFECT, "BST_FILE_DIALOG_SAVE_EFFECT", "save-effect" },
  { BST_FILE_DIALOG_SAVE_INSTRUMENT, "BST_FILE_DIALOG_SAVE_INSTRUMENT", "save-instrument" },
  { BST_FILE_DIALOG_MODE_MASK, "BST_FILE_DIALOG_MODE_MASK", "mode-mask" },
  { BST_FILE_DIALOG_ALLOW_DIRS, "BST_FILE_DIALOG_ALLOW_DIRS", "allow-dirs" },
  { BST_FILE_DIALOG_FLAG_MASK, "BST_FILE_DIALOG_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstmarker.h --- */
#include	"bstmarker.h"
/* BstMarkerType
 */
static GEnumValue bst_marker_type_values[] = {
  { BST_MARKER_NONE, "BST_MARKER_NONE", "none" },
  { BST_MARKER_RED, "BST_MARKER_RED", "red" },
  { BST_MARKER_GREEN, "BST_MARKER_GREEN", "green" },
  { BST_MARKER_BLUE, "BST_MARKER_BLUE", "blue" },
  { 0, NULL, NULL }
};


/* --- bstmenus.h --- */
#include	"bstmenus.h"
/* BstChoiceFlags
 */
static GFlagsValue bst_choice_flags_values[] = {
  { BST_CHOICE_TYPE_SEPARATOR, "BST_CHOICE_TYPE_SEPARATOR", "type-separator" },
  { BST_CHOICE_TYPE_TITLE, "BST_CHOICE_TYPE_TITLE", "type-title" },
  { BST_CHOICE_TYPE_TEXT, "BST_CHOICE_TYPE_TEXT", "type-text" },
  { BST_CHOICE_TYPE_ITEM, "BST_CHOICE_TYPE_ITEM", "type-item" },
  { BST_CHOICE_TYPE_SUBMENU, "BST_CHOICE_TYPE_SUBMENU", "type-submenu" },
  { BST_CHOICE_TYPE_MASK, "BST_CHOICE_TYPE_MASK", "type-mask" },
  { BST_CHOICE_FLAG_INSENSITIVE, "BST_CHOICE_FLAG_INSENSITIVE", "flag-insensitive" },
  { BST_CHOICE_FLAG_DEFAULT, "BST_CHOICE_FLAG_DEFAULT", "flag-default" },
  { BST_CHOICE_FLAG_MASK, "BST_CHOICE_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstqsampler.h --- */
#include	"bstqsampler.h"
/* BstQSamplerType
 */
static GFlagsValue bst_qsampler_type_values[] = {
  { BST_QSAMPLER_ACTIVE, "BST_QSAMPLER_ACTIVE", "active" },
  { BST_QSAMPLER_SELECTED, "BST_QSAMPLER_SELECTED", "selected" },
  { BST_QSAMPLER_PRELIGHT, "BST_QSAMPLER_PRELIGHT", "prelight" },
  { BST_QSAMPLER_MARK_MASK, "BST_QSAMPLER_MARK_MASK", "mark-mask" },
  { BST_QSAMPLER_REGION_MASK, "BST_QSAMPLER_REGION_MASK", "region-mask" },
  { BST_QSAMPLER_MARK, "BST_QSAMPLER_MARK", "mark" },
  { BST_QSAMPLER_MASK, "BST_QSAMPLER_MASK", "mask" },
  { BST_QSAMPLER_SKIP, "BST_QSAMPLER_SKIP", "skip" },
  { BST_QSAMPLER_NEEDS_DRAW, "BST_QSAMPLER_NEEDS_DRAW", "needs-draw" },
  { BST_QSAMPLER_DIRTY, "BST_QSAMPLER_DIRTY", "dirty" },
  { 0, NULL, NULL }
};

/* BstQSamplerDrawMode
 */
static GEnumValue bst_qsampler_draw_mode_values[] = {
  { BST_QSAMPLER_DRAW_CRANGE, "BST_QSAMPLER_DRAW_CRANGE", "crange" },
  { BST_QSAMPLER_DRAW_CSHAPE, "BST_QSAMPLER_DRAW_CSHAPE", "cshape" },
  { BST_QSAMPLER_DRAW_ZERO_SHAPE, "BST_QSAMPLER_DRAW_ZERO_SHAPE", "zero-shape" },
  { BST_QSAMPLER_DRAW_MINIMUM_LINE, "BST_QSAMPLER_DRAW_MINIMUM_LINE", "minimum-line" },
  { BST_QSAMPLER_DRAW_MIDDLE_LINE, "BST_QSAMPLER_DRAW_MIDDLE_LINE", "middle-line" },
  { BST_QSAMPLER_DRAW_MAXIMUM_LINE, "BST_QSAMPLER_DRAW_MAXIMUM_LINE", "maximum-line" },
  { BST_QSAMPLER_DRAW_MINIMUM_SHAPE, "BST_QSAMPLER_DRAW_MINIMUM_SHAPE", "minimum-shape" },
  { BST_QSAMPLER_DRAW_MAXIMUM_SHAPE, "BST_QSAMPLER_DRAW_MAXIMUM_SHAPE", "maximum-shape" },
  { 0, NULL, NULL }
};


/* --- bstradiotools.h --- */
#include	"bstradiotools.h"
/* BstRadioToolsFlags
 */
static GFlagsValue bst_radio_tools_flags_values[] = {
  { BST_RADIO_TOOLS_NONE, "BST_RADIO_TOOLS_NONE", "none" },
  { BST_RADIO_TOOLS_TOOLBAR, "BST_RADIO_TOOLS_TOOLBAR", "toolbar" },
  { BST_RADIO_TOOLS_PALETTE, "BST_RADIO_TOOLS_PALETTE", "palette" },
  { 0, NULL, NULL }
};


/* --- bstsegment.h --- */
#include	"bstsegment.h"
/* BstSegmentType
 */
static GEnumValue bst_segment_type_values[] = {
  { BST_SEGMENT_LINE, "BST_SEGMENT_LINE", "line" },
  { 0, NULL, NULL }
};


/* --- bstdefs.h --- */
#include	"bstdefs.h"
/* BstActionRegions
 */
static GFlagsValue bst_action_regions_values[] = {
  { BST_ACTION_NONE, "BST_ACTION_NONE", "none" },
  { BST_ACTION_APP_FIRST, "BST_ACTION_APP_FIRST", "app-first" },
  { BST_ACTION_WAVE_FIRST, "BST_ACTION_WAVE_FIRST", "wave-first" },
  { BST_ACTION_PART_FIRST, "BST_ACTION_PART_FIRST", "part-first" },
  { BST_ACTION_TRACK_FIRST, "BST_ACTION_TRACK_FIRST", "track-first" },
  { 0, NULL, NULL }
};

/* BstQuantizationType
 */
static GEnumValue bst_quantization_type_values[] = {
  { BST_QUANTIZE_NONE, "BST_QUANTIZE_NONE", "none" },
  { BST_QUANTIZE_NOTE_1, "BST_QUANTIZE_NOTE_1", "note-1" },
  { BST_QUANTIZE_NOTE_2, "BST_QUANTIZE_NOTE_2", "note-2" },
  { BST_QUANTIZE_NOTE_4, "BST_QUANTIZE_NOTE_4", "note-4" },
  { BST_QUANTIZE_NOTE_8, "BST_QUANTIZE_NOTE_8", "note-8" },
  { BST_QUANTIZE_NOTE_16, "BST_QUANTIZE_NOTE_16", "note-16" },
  { BST_QUANTIZE_NOTE_32, "BST_QUANTIZE_NOTE_32", "note-32" },
  { BST_QUANTIZE_NOTE_64, "BST_QUANTIZE_NOTE_64", "note-64" },
  { BST_QUANTIZE_NOTE_128, "BST_QUANTIZE_NOTE_128", "note-128" },
  { BST_QUANTIZE_TACT, "BST_QUANTIZE_TACT", "tact" },
  { 0, NULL, NULL }
};


/* Generated data ends here */

==> beast-0.5.6.tar.gz: beast-0.5.6/beast-gtk/bstenum_arrays.c <==

/* Generated data (by glib-mkenums) */


/* --- bstfiledialog.h --- */
#include	"bstfiledialog.h"
/* BstFileDialogMode
 */
static GEnumValue bst_file_dialog_mode_values[] = {
  { BST_FILE_DIALOG_OPEN_PROJECT, "BST_FILE_DIALOG_OPEN_PROJECT", "open-project" },
  { BST_FILE_DIALOG_MERGE_PROJECT, "BST_FILE_DIALOG_MERGE_PROJECT", "merge-project" },
  { BST_FILE_DIALOG_SAVE_PROJECT, "BST_FILE_DIALOG_SAVE_PROJECT", "save-project" },
  { BST_FILE_DIALOG_IMPORT_MIDI, "BST_FILE_DIALOG_IMPORT_MIDI", "import-midi" },
  { BST_FILE_DIALOG_SELECT_DIR, "BST_FILE_DIALOG_SELECT_DIR", "select-dir" },
  { BST_FILE_DIALOG_LOAD_WAVE, "BST_FILE_DIALOG_LOAD_WAVE", "load-wave" },
  { BST_FILE_DIALOG_LOAD_WAVE_LIB, "BST_FILE_DIALOG_LOAD_WAVE_LIB", "load-wave-lib" },
  { BST_FILE_DIALOG_MERGE_EFFECT, "BST_FILE_DIALOG_MERGE_EFFECT", "merge-effect" },
  { BST_FILE_DIALOG_MERGE_INSTRUMENT, "BST_FILE_DIALOG_MERGE_INSTRUMENT", "merge-instrument" },
  { BST_FILE_DIALOG_SAVE_EFFECT, "BST_FILE_DIALOG_SAVE_EFFECT", "save-effect" },
  { BST_FILE_DIALOG_SAVE_INSTRUMENT, "BST_FILE_DIALOG_SAVE_INSTRUMENT", "save-instrument" },
  { BST_FILE_DIALOG_MODE_MASK, "BST_FILE_DIALOG_MODE_MASK", "mode-mask" },
  { BST_FILE_DIALOG_ALLOW_DIRS, "BST_FILE_DIALOG_ALLOW_DIRS", "allow-dirs" },
  { BST_FILE_DIALOG_FLAG_MASK, "BST_FILE_DIALOG_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstmarker.h --- */
#include	"bstmarker.h"
/* BstMarkerType
 */
static GEnumValue bst_marker_type_values[] = {
  { BST_MARKER_NONE, "BST_MARKER_NONE", "none" },
  { BST_MARKER_RED, "BST_MARKER_RED", "red" },
  { BST_MARKER_GREEN, "BST_MARKER_GREEN", "green" },
  { BST_MARKER_BLUE, "BST_MARKER_BLUE", "blue" },
  { 0, NULL, NULL }
};


/* --- bstmenus.h --- */
#include	"bstmenus.h"
/* BstChoiceFlags
 */
static GFlagsValue bst_choice_flags_values[] = {
  { BST_CHOICE_TYPE_SEPARATOR, "BST_CHOICE_TYPE_SEPARATOR", "type-separator" },
  { BST_CHOICE_TYPE_TITLE, "BST_CHOICE_TYPE_TITLE", "type-title" },
  { BST_CHOICE_TYPE_TEXT, "BST_CHOICE_TYPE_TEXT", "type-text" },
  { BST_CHOICE_TYPE_ITEM, "BST_CHOICE_TYPE_ITEM", "type-item" },
  { BST_CHOICE_TYPE_SUBMENU, "BST_CHOICE_TYPE_SUBMENU", "type-submenu" },
  { BST_CHOICE_TYPE_MASK, "BST_CHOICE_TYPE_MASK", "type-mask" },
  { BST_CHOICE_FLAG_INSENSITIVE, "BST_CHOICE_FLAG_INSENSITIVE", "flag-insensitive" },
  { BST_CHOICE_FLAG_DEFAULT, "BST_CHOICE_FLAG_DEFAULT", "flag-default" },
  { BST_CHOICE_FLAG_MASK, "BST_CHOICE_FLAG_MASK", "flag-mask" },
  { 0, NULL, NULL }
};


/* --- bstqsampler.h --- */
#include	"bstqsampler.h"
/* BstQSamplerType
 */
static GFlagsValue bst_qsampler_type_values[] = {
  { BST_QSAMPLER_ACTIVE, "BST_QSAMPLER_ACTIVE", "active" },
  { BST_QSAMPLER_SELECTED, "BST_QSAMPLER_SELECTED", "selected" },
  { BST_QSAMPLER_PRELIGHT, "BST_QSAMPLER_PRELIGHT", "prelight" },
  { BST_QSAMPLER_MARK_MASK, "BST_QSAMPLER_MARK_MASK", "mark-mask" },
  { BST_QSAMPLER_REGION_MASK, "BST_QSAMPLER_REGION_MASK", "region-mask" },
  { BST_QSAMPLER_MARK, "BST_QSAMPLER_MARK", "mark" },
  { BST_QSAMPLER_MASK, "BST_QSAMPLER_MASK", "mask" },
  { BST_QSAMPLER_SKIP, "BST_QSAMPLER_SKIP", "skip" },
  { BST_QSAMPLER_NEEDS_DRAW, "BST_QSAMPLER_NEEDS_DRAW", "needs-draw" },
  { BST_QSAMPLER_DIRTY, "BST_QSAMPLER_DIRTY", "dirty" },
  { 0, NULL, NULL }
};

/* BstQSamplerDrawMode
 */
static GEnumValue bst_qsampler_draw_mode_values[] = {
  { BST_QSAMPLER_DRAW_CRANGE, "BST_QSAMPLER_DRAW_CRANGE", "crange" },
  { BST_QSAMPLER_DRAW_CSHAPE, "BST_QSAMPLER_DRAW_CSHAPE", "cshape" },
  { BST_QSAMPLER_DRAW_ZERO_SHAPE, "BST_QSAMPLER_DRAW_ZERO_SHAPE", "zero-shape" },
  { BST_QSAMPLER_DRAW_MINIMUM_LINE, "BST_QSAMPLER_DRAW_MINIMUM_LINE", "minimum-line" },
  { BST_QSAMPLER_DRAW_MIDDLE_LINE, "BST_QSAMPLER_DRAW_MIDDLE_LINE", "middle-line" },
  { BST_QSAMPLER_DRAW_MAXIMUM_LINE, "BST_QSAMPLER_DRAW_MAXIMUM_LINE", "maximum-line" },
  { BST_QSAMPLER_DRAW_MINIMUM_SHAPE, "BST_QSAMPLER_DRAW_MINIMUM_SHAPE", "minimum-shape" },
  { BST_QSAMPLER_DRAW_MAXIMUM_SHAPE, "BST_QSAMPLER_DRAW_MAXIMUM_SHAPE", "maximum-shape" },
  { 0, NULL, NULL }
};


/* --- bstsegment.h --- */
#include	"bstsegment.h"
/* BstSegmentType
 */
static GEnumValue bst_segment_type_values[] = {
  { BST_SEGMENT_LINE, "BST_SEGMENT_LINE", "line" },
  { 0, NULL, NULL }
};


/* --- bstdefs.h --- */
#include	"bstdefs.h"
/* BstQuantizationType
 */
static GEnumValue bst_quantization_type_values[] = {
  { BST_QUANTIZE_NONE, "BST_QUANTIZE_NONE", "none" },
  { BST_QUANTIZE_NOTE_1, "BST_QUANTIZE_NOTE_1", "note-1" },
  { BST_QUANTIZE_NOTE_2, "BST_QUANTIZE_NOTE_2", "note-2" },
  { BST_QUANTIZE_NOTE_4, "BST_QUANTIZE_NOTE_4", "note-4" },
  { BST_QUANTIZE_NOTE_8, "BST_QUANTIZE_NOTE_8", "note-8" },
  { BST_QUANTIZE_NOTE_16, "BST_QUANTIZE_NOTE_16", "note-16" },
  { BST_QUANTIZE_NOTE_32, "BST_QUANTIZE_NOTE_32", "note-32" },
  { BST_QUANTIZE_NOTE_64, "BST_QUANTIZE_NOTE_64", "note-64" },
  { BST_QUANTIZE_NOTE_128, "BST_QUANTIZE_NOTE_128", "note-128" },
  { BST_QUANTIZE_TACT, "BST_QUANTIZE_TACT", "tact" },
  { 0, NULL, NULL }
};


/* Generated data ends here */
